@@ -1,7 +1,6 @@
 #![feature(box_into_inner)]
 extern crate proc_macro;
 
-use hex;
 use proc_macro::TokenStream;
 use proc_macro2::{Ident, Span};
 use proc_macro_error::{abort, abort_call_site, proc_macro_error};
@@ -93,7 +92,7 @@ pub fn ewasm_main(attr: TokenStream, item: TokenStream) -> TokenStream {
         syn::ReturnType::Type(_, boxed) => match Box::into_inner(boxed) {
             syn::Type::Path(syn::TypePath { path: p, .. }) => {
                 let mut ok_type: Option<String> = None;
-                let mut segments = p.segments.clone();
+                let mut segments = p.segments;
                 while let Some(pair) = segments.pop() {
                     ok_type = match pair.into_value() {
                         syn::PathSegment {
@@ -103,21 +102,16 @@ pub fn ewasm_main(attr: TokenStream, item: TokenStream) -> TokenStream {
                                 ),
                             ..
                         } => match a.first() {
-                            Some(a) => match a {
-                                syn::GenericArgument::Type(syn::Type::Path(syn::TypePath {
-                                    path: p,
-                                    ..
-                                })) => {
-                                    if let Some(syn::PathSegment { ident: i, .. }) =
-                                        p.segments.last()
-                                    {
-                                        Some(i.to_string())
-                                    } else {
-                                        None
-                                    }
+                            Some(syn::GenericArgument::Type(syn::Type::Path(syn::TypePath {
+                                path: p,
+                                ..
+                            }))) => {
+                                if let Some(syn::PathSegment { ident: i, .. }) = p.segments.last() {
+                                    Some(i.to_string())
+                                } else {
+                                    None
                                 }
-                                _ => None,
-                            },
+                            }
                             _ => None,
                         },
                         _ => None,
@@ -252,15 +246,13 @@ pub fn ewasm_fn(attr: TokenStream, item: TokenStream) -> TokenStream {
         (None, "{}".to_string())
     } else if attr_str.starts_with('{') {
         (None, attr_str.split_whitespace().collect())
+    } else if let Some((head, tail)) = attr_str.split_once(',') {
+        (
+            Some(head.replace("\"", "")),
+            tail.split_whitespace().collect(),
+        )
     } else {
-        if let Some((head, tail)) = attr_str.split_once(',') {
-            (
-                Some(head.replace("\"", "")),
-                tail.split_whitespace().collect(),
-            )
-        } else {
-            (Some(attr_str.replace("\"", "")), "{}".to_string())
-        }
+        (Some(attr_str.replace("\"", "")), "{}".to_string())
     };
 
     let input = syn::parse_macro_input!(item as syn::ItemFn);
@@ -325,7 +317,7 @@ pub fn ewasm_fn(attr: TokenStream, item: TokenStream) -> TokenStream {
 pub fn ewasm_constructor(_attr: TokenStream, item: TokenStream) -> TokenStream {
     let input = syn::parse_macro_input!(item as syn::ItemFn);
     let name = &input.sig.ident;
-    if name.to_string() != "constructor" {
+    if *name != "constructor" {
         abort!(input.sig.ident, "please name the function as `constructor`");
     }
     let result = quote! {
@@ -382,13 +374,11 @@ pub fn ewasm_lib_fn(attr: TokenStream, item: TokenStream) -> TokenStream {
     let (hex_str, abi_str) = if attr_str.is_empty() {
         (None, "{}".to_string())
     } else if attr_str.starts_with('{') {
-        (None, attr_str.to_string())
+        (None, attr_str)
+    } else if let Some((head, tail)) = attr_str.split_once(',') {
+        (Some(head.replace("\"", "")), tail.to_string())
     } else {
-        if let Some((head, tail)) = attr_str.split_once(',') {
-            (Some(head.replace("\"", "")), tail.to_string())
-        } else {
-            (Some(attr_str.replace("\"", "")), "{}".to_string())
-        }
+        (Some(attr_str.replace("\"", "")), "{}".to_string())
     };
 
     let input = syn::parse_macro_input!(item as syn::ItemFn);
@@ -808,14 +798,6 @@ pub fn derive_table(item: TokenStream) -> TokenStream {
             pub records: Vec<#wrapper_name>
         }
 
-        impl sewup::primitives::IntoEwasmAny for #protocol_name {
-            fn into_ewasm_any(self) -> sewup::primitives::EwasmAny {
-                sewup::primitives::EwasmAny {
-                    bin: sewup::bincode::serialize(&self).expect("The input should be serializable")
-                }
-            }
-        }
-
         impl #protocol_name {
             pub fn set_select_fields(&mut self, fields: Vec<String>) {
                 if fields.is_empty() {
@@ -897,7 +879,6 @@ pub fn derive_table(item: TokenStream) -> TokenStream {
         #[cfg(target_arch = "wasm32")]
         pub mod #lower_name {
             use super::*;
-            use sewup::primitives::IntoEwasmAny;
             pub type Protocol = #protocol_name;
             pub type Wrapper = #wrapper_name;
             pub type _InstanceType = #struct_name;
@@ -938,12 +919,12 @@ pub fn derive_table(item: TokenStream) -> TokenStream {
                         }
                     }
                     let p: #protocol_name = raw_output.into();
-                    Ok(p.into_ewasm_any())
+                    Ok(p.into())
                 } else {
                     let raw_output = table.get_record(proc.records[0].id.unwrap_or_default())?;
                     let mut output_proc: Protocol = raw_output.into();
                     output_proc.records[0].id = proc.records[0].id;
-                    Ok(output_proc.into_ewasm_any())
+                    Ok(output_proc.into())
                 }
             }
             pub fn create(proc: Protocol) -> sewup::Result<sewup::primitives::EwasmAny> {
@@ -951,21 +932,21 @@ pub fn derive_table(item: TokenStream) -> TokenStream {
                 let mut output_proc = proc.clone();
                 output_proc.records[0].id = Some(table.add_record(proc.records[0].clone().into())?);
                 table.commit()?;
-                Ok(output_proc.into_ewasm_any())
+                Ok(output_proc.into())
             }
             pub fn update(proc: Protocol) -> sewup::Result<sewup::primitives::EwasmAny> {
                 let mut table = sewup::rdb::Db::load(None)?.table::<_InstanceType>()?;
                 let id = proc.records[0].id.unwrap_or_default();
                 table.update_record(id, Some(proc.records[0].clone().into()))?;
                 table.commit()?;
-                Ok(proc.into_ewasm_any())
+                Ok(proc.into())
             }
             pub fn delete(proc: Protocol) -> sewup::Result<sewup::primitives::EwasmAny> {
                 let mut table = sewup::rdb::Db::load(None)?.table::<_InstanceType>()?;
                 let id = proc.records[0].id.unwrap_or_default();
                 table.update_record(id, None)?;
                 table.commit()?;
-                Ok(proc.into_ewasm_any())
+                Ok(proc.into())
             }
         }
         #[cfg(not(target_arch = "wasm32"))]
